@@ -49,7 +49,7 @@ class StringCommandHandler(BaseHandler[str, CCT]):
             called when :meth:`check_update` has determined that an update should be processed by
             this handler. Callback signature::
 
-                async def callback(update: Update, context: CallbackContext)
+                async def callback(update: str, context: CallbackContext)
 
             The return value of the callback is usually ignored except for the special case of
             :class:`telegram.ext.ConversationHandler`.
@@ -98,8 +98,8 @@ class StringCommandHandler(BaseHandler[str, CCT]):
     def collect_additional_context(
         self,
         context: CCT,
-        update: str,
-        application: "Application[Any, CCT, Any, Any, Any, Any]",
+        update: str,  # noqa: ARG002
+        application: "Application[Any, CCT, Any, Any, Any, Any]",  # noqa: ARG002
         check_result: Optional[List[str]],
     ) -> None:
         """Add text after the command to :attr:`CallbackContext.args` as list, split on single
