@@ -378,7 +378,7 @@ class TestAudioWithRequest(TestAudioBase):
             )
             assert message.reply_to_message is None
         else:
-            with pytest.raises(BadRequest, match="Message to reply not found"):
+            with pytest.raises(BadRequest, match="Message to be replied not found"):
                 await default_bot.send_audio(
                     chat_id, audio, reply_to_message_id=reply_to_message.message_id
                 )
