@@ -40,6 +40,7 @@ def inline_query_result_cached_gif():
         caption_entities=TestInlineQueryResultCachedGifBase.caption_entities,
         input_message_content=TestInlineQueryResultCachedGifBase.input_message_content,
         reply_markup=TestInlineQueryResultCachedGifBase.reply_markup,
+        show_caption_above_media=TestInlineQueryResultCachedGifBase.show_caption_above_media,
     )
 
 
@@ -53,6 +54,7 @@ class TestInlineQueryResultCachedGifBase:
     caption_entities = [MessageEntity(MessageEntity.ITALIC, 0, 7)]
     input_message_content = InputTextMessageContent("input_message_content")
     reply_markup = InlineKeyboardMarkup([[InlineKeyboardButton("reply_markup")]])
+    show_caption_above_media = True
 
 
 class TestInlineQueryResultCachedGifWithoutRequest(TestInlineQueryResultCachedGifBase):
@@ -75,6 +77,10 @@ class TestInlineQueryResultCachedGifWithoutRequest(TestInlineQueryResultCachedGi
             == self.input_message_content.to_dict()
         )
         assert inline_query_result_cached_gif.reply_markup.to_dict() == self.reply_markup.to_dict()
+        assert (
+            inline_query_result_cached_gif.show_caption_above_media
+            == self.show_caption_above_media
+        )
 
     def test_caption_entities_always_tuple(self):
         result = InlineQueryResultCachedGif(self.id_, self.gif_file_id)
@@ -110,6 +116,10 @@ class TestInlineQueryResultCachedGifWithoutRequest(TestInlineQueryResultCachedGi
             inline_query_result_cached_gif_dict["reply_markup"]
             == inline_query_result_cached_gif.reply_markup.to_dict()
         )
+        assert (
+            inline_query_result_cached_gif_dict["show_caption_above_media"]
+            == inline_query_result_cached_gif.show_caption_above_media
+        )
 
     def test_equality(self):
         a = InlineQueryResultCachedGif(self.id_, self.gif_file_id)
